@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::CheckPrereqsIndexed;
 # ABSTRACT: prevent a release if you have prereqs not found on CPAN
-$Dist::Zilla::Plugin::CheckPrereqsIndexed::VERSION = '0.017';
+$Dist::Zilla::Plugin::CheckPrereqsIndexed::VERSION = '0.018';
 use 5.10.0; # //
 use Moose;
 
@@ -23,7 +23,7 @@ use Moose;
 
 with 'Dist::Zilla::Role::BeforeRelease';
 
-use List::MoreUtils qw(any uniq);
+use List::Util 1.33 qw(any);
 
 use namespace::autoclean;
 
@@ -156,7 +156,7 @@ Dist::Zilla::Plugin::CheckPrereqsIndexed - prevent a release if you have prereqs
 
 =head1 VERSION
 
-version 0.017
+version 0.018
 
 =head1 OVERVIEW
 
